@@ -126,10 +126,10 @@ enum pjmedia_video_pt
 
      PJMEDIA_RTP_PT_VP8,        /* used by VPX                */
      PJMEDIA_RTP_PT_VP8_RSV1,   /* used by MediaCodec         */
-     PJMEDIA_RTP_PT_VP8_RSV2,
+     PJMEDIA_RTP_PT_VP8_RSV2,   /* used by ffmpeg avcodec     */
      PJMEDIA_RTP_PT_VP9,        /* used by VPX                */
      PJMEDIA_RTP_PT_VP9_RSV1,   /* used by MediaCodec         */
-     PJMEDIA_RTP_PT_VP9_RSV2,
+     PJMEDIA_RTP_PT_VP9_RSV2,   /* used by ffmpeg avcodec     */
 
      /* Caution!
       * Ensure the value of the last pt above is <= 127.
